==> atmc-http-0.0.2.0014-sources.jar: com/digiwin/athena/atmc/http/restful/atdm/AtdmService.java <==
package com.digiwin.athena.atmc.http.restful.atdm;

import com.digiwin.athena.appcore.domain.BaseResultDTO;
import com.digiwin.athena.atmc.http.domain.action.SubmitActionDTO;
import com.digiwin.athena.atmc.http.restful.aglie.model.QueryDataByActionVO;
import com.digiwin.athena.atmc.http.restful.atdm.model.RecycleRecordStateChangeDTO;
import net.sf.json.JSONObject;

import java.util.List;
import java.util.Map;

public interface AtdmService {

    /**
     * 提交
     *
     * @param submitAction
     * @return
     */
    Map submitTask(SubmitActionDTO submitAction);

    /**
     * 执行
     *
     * @param submitAction
     * @return
     */
    Map executeTask(SubmitActionDTO submitAction);

    /**
     * 根据actionId查询
     *
     * @param action
     * @return
     */
    BaseResultDTO queryByActionId(Map action);

    /**
     * 提交合并的任务
     *
     * @param mergeActionList
     * @return
     */
    List<Map> submitMergeTask(List<SubmitActionDTO> mergeActionList);

    /**
     * 将回收站记录标记为过期状态
     *
     * @param recycleRecordStateChangeDTO
     * @return
     */
    void markRecycleRecordExpired(RecycleRecordStateChangeDTO recycleRecordStateChangeDTO);

    /**
     * 将回收站记录标记为未过期状态
     *
     * @param recycleRecordStateChangeDTO
     * @return
     */
    void markRecycleRecordUnexpired(RecycleRecordStateChangeDTO recycleRecordStateChangeDTO);

    /**
     * 将回收站记录标记为删除状态（硬删除）
     *
     * @param recycleRecordStateChangeDTO
     * @return
     */
    void markRecycleRecordDeleted(RecycleRecordStateChangeDTO recycleRecordStateChangeDTO);

    /**
     * 获取任务卡CheckItems等数
     *
     * @return
     */
    BaseResultDTO<JSONObject> getDataByAction(QueryDataByActionVO queryDataByActionVO);

}

==> atmc-http-0.0.2.0039-sources.jar: com/digiwin/athena/atmc/http/restful/atdm/AtdmService.java <==
package com.digiwin.athena.atmc.http.restful.atdm;

import com.digiwin.athena.appcore.auth.domain.AuthoredUser;
import com.digiwin.athena.appcore.domain.BaseResultDTO;
import com.digiwin.athena.atmc.http.domain.action.MergeSubmitActionDTO;
import com.digiwin.athena.atmc.http.domain.action.SubmitActionDTO;
import com.digiwin.athena.atmc.http.restful.aglie.model.QueryDataByActionVO;
import com.digiwin.athena.atmc.http.restful.atdm.model.QueryResultSet;
import com.digiwin.athena.atmc.http.restful.atdm.model.RecycleRecordStateChangeDTO;
import net.sf.json.JSONObject;

import java.util.List;
import java.util.Map;

public interface AtdmService {

    /**
     * 提交
     *
     * @param submitAction
     * @return
     */
    Map submitTask(SubmitActionDTO submitAction);

    /**
     * 执行
     *
     * @param submitAction
     * @return
     */
    Map executeTask(SubmitActionDTO submitAction);

    /**
     * 根据actionId查询
     *
     * @param action
     * @return
     */
    BaseResultDTO queryByActionId(Map action);

    /**
     * 提交合并的任务
     *
     * @param mergeActionList
     * @return
     */
    List<Map> submitMergeTask(List<SubmitActionDTO> mergeActionList);

    /**
     * 提交合并的任务_支持跨BK
     *
     * @param mergeActionList
     * @return
     */
    List<Map> submitMergeTaskCrossBk(List<SubmitActionDTO> mergeActionList);

    /**
     * 将回收站记录标记为过期状态
     *
     * @param recycleRecordStateChangeDTO
     * @return
     */
    void markRecycleRecordExpired(RecycleRecordStateChangeDTO recycleRecordStateChangeDTO);

    /**
     * 将回收站记录标记为未过期状态
     *
     * @param recycleRecordStateChangeDTO
     * @return
     */
    void markRecycleRecordUnexpired(RecycleRecordStateChangeDTO recycleRecordStateChangeDTO);

    /**
     * 将回收站记录标记为删除状态（硬删除）
     *
     * @param recycleRecordStateChangeDTO
     * @return
     */
    void markRecycleRecordDeleted(RecycleRecordStateChangeDTO recycleRecordStateChangeDTO);

    /**
     * 获取任务卡CheckItems等数
     *
     * @return
     */
    BaseResultDTO<JSONObject> getDataByAction(QueryDataByActionVO queryDataByActionVO);


    /**
     * 退回
     *
     * @param mergeActionList
     * @return
     */
    List<Map> submitReturnTask(List<SubmitActionDTO> mergeActionList);

    /**
     * 获取应用业务数据
     */
    QueryResultSet getResultSet(Map map, AuthoredUser authoredUser);

    List<Map> mergeTaskRetry(MergeSubmitActionDTO mergeSubmitAction);
}
